==> bos-0.9.1.2.tar.gz: bos-0.9.1.2/extensions/bos_default/plugin/bos_user.rb <==
# $Id: bos_user.rb,v 1.14 2005/03/04 01:14:44 nisi Exp $

def pre_bos_user_init
	Session['uid'] = nil if Session['uid'] == ""
	if Session['uid'] then
		@login_user = BosUser.new(Session['uid'])
	end
	tu = Request["bos_user_login_uid"] || ""
	tp = Request["bos_user_login_pwd"] || ""
	if tu != "" && tp != "" then
		@login_user = BosUser.new(tu)
		@bos_login_err = @login_user.login(tp)
	end
	
	if Request["bos_user_logout"] == 'on' && @login_user then
		@login_user.logout
	end
end

def bos_user_edit
	return nil unless @login_user
	return nil unless Request["uid"]
	uid = Request["uid"]
	user = BosUser.new(uid)
	
	if @login_user == 'a' || @login_user[:user_id] == user[:user_id] then
		if Request["bos_user_edit"] == "on" then
			begin
				bidate = Date.parse(Request["in_bos_birth"])
			rescue
				bidate = nil
			end
			user[:password]     = Request["in_bos_password"] == "" ? user[:password] : BosUser::cmd5(Request["in_bos_password"])
			user[:mail_address] = Request["in_bos_mail_address"]
			user[:sex]          = Request["in_bos_sex"]
			user[:birth]        = bidate
			user[:user_level]   = Request["in_bos_user_level"]
			user.commit
		end
		{
			:bos_user_id         => user[:user_id],
			:uid                 => a(:value => user[:user_id]),
			:in_bos_user_id      => a(:value => user[:user_id]){{}},
			:in_bos_password     => a(:value => "", :type =>"password" ){{}},
			:in_bos_mail_address => a(:value => user[:mail_address]){{}},
			:in_bos_sex          => {:user_sex => form_select(
				[{'f' => ''},{'m' => ''},{'o' => ''}],user[:sex])},
			:in_bos_birth   => a(:value => (user[:birth] ? user[:birth].to_sql : "")){{}},
			:in_bos_user_level   => {:user_level => form_select(
				[{'a' => ''},{'p' => '̥桼'},{'o' => ''}],user[:user_level])}
		}
	else
		"¤ޤ"
	end
end

def bos_user_newlink
	a(:href => "?uid="){{}}
end

def bos_user_listlink
	a(:href => "?"){{}}
end

def bos_user_list_navi
	bos_user_list_pre unless @login_user_list
	page_navi(@login_user_maxpage,"page",{"pagect" => 10,:script_name => "user.htm"})
end

def bos_user_list
	bos_user_list_pre unless @login_user_list
	{:bos_user_list_rec => @login_user_list}
end

def bos_user_list_pre
	user = BosUser.new("")
	@login_user_list = []
	rec,info = @login_user.get_list(Request["page"],Request["pagect"])
	@login_user_maxpage = info[:max_page]
	rec.each{|rs|
		@login_user_list << {
			:bos_user_list_id    => rs[:user_id],
			:bos_user_list_level => rs[:user_level],
			:bos_user_list_edit  => a(:href => "?uid=#{rs[:user_id]}"){{}}} }
end

def bos_user_login
	return nil if Session['uid']
	{:bos_user_login_form => {
		:bos_user_login_uid => a(:name => "bos_user_login_uid", :value => (Request["bos_user_login_uid"] || "")){{}},
		:bos_user_login_pwd => a(:name => "bos_user_login_pwd", :value => ""){{}}
	}}
end

def bos_user_logout
	return nil unless Session['uid']
	true
end

def bos_user_login_user_id
	return nil unless @login_user
	@login_user[:user_id]
end

def bos_user_admin_only_dev
	return nil unless @login_user
	@login_user == "a"
end

def bos_user_admin_only_page
	if @login_user && @login_user == "a" then
		# ǧʤ󤫤ää
	else
		print "Location: #{Prop[:site_url]}#{Prop[:err_doc]}\n\n"
	end
end

def bos_user_admin_items
	ret = []
	outpage = ["index","admside"]
	Dir.glob("#{Prop[:admin_dir]}/*.#{Prop[:bos_template]}").sort.each{|fl|
		if /.+\/(.+)\.#{Prop[:bos_template]}/ =~ fl then
			tmpt = $1
			ret << {:admin_item => a(:href => "#{tmpt}.#{Prop[:bos_template]}"){ tmpt } } unless outpage.include?(tmpt)
		end
	}
	ret
end

def bos_user_add_new
	ret = {
		:user_add_form => nil,
		:user_add_send => nil,
		:user_add_err => nil }
	if !Request["in_bos_user_id"] && !Request["in_bos_password"] then
		ret[:user_add_form] = true
	elsif Request["in_bos_user_id"] || Request["in_bos_password"] then
		ret[:user_add_form] = {
			:in_bos_user_id => a(:values => Request["in_bos_user_id"] || ""),
			:in_bos_password => a(:values => ""),
			:in_bos_mail_address => a(:values => Request["in_bos_mail_address"] || ""),
		}
		ret[:user_add_err] = "ID 顼"
	else
		tmpu = BosUser.new(Request["in_bos_user_id"])
		tmpu 
	end
end

==> bos-0.9.1.3.tar.gz: bos-0.9.1.3/extensions/bos_default/plugin/bos_user.rb <==
# $Id: bos_user.rb,v 1.15 2005/04/10 08:48:56 nisi Exp $

def pre_bos_user_init
	Session['uid'] = nil if Session['uid'] == ""
	if Session['uid'] then
		@login_user = BosUser.new(Session['uid'])
	end
	tu = Request["bos_user_login_uid"] || ""
	tp = Request["bos_user_login_pwd"] || ""
	if tu != "" && tp != "" then
		@login_user = BosUser.new(tu)
		@bos_login_err = @login_user.login(tp)
	end
	
	if Request["bos_user_logout"] == 'on' && @login_user then
		@login_user.logout
	end
end

def bos_user_edit
	return nil unless @login_user
	return nil unless Request["uid"]
	uid = Request["uid"]
	user = BosUser.new(uid)
	
	if @login_user == 'a' || @login_user[:user_id] == user[:user_id] then
		if Request["bos_user_edit"] == "on" then
			begin
				bidate = Date.parse(Request["in_bos_birth"])
			rescue
				bidate = nil
			end
			user[:password]     = Request["in_bos_password"] == "" ? user[:password] : BosUser::cmd5(Request["in_bos_password"])
			user[:mail_address] = Request["in_bos_mail_address"]
			user[:sex]          = Request["in_bos_sex"]
			user[:birth]        = bidate
			user[:user_level]   = Request["in_bos_user_level"]
			user.commit
		end
		ret = {
			:uid                 => a(:value => user[:user_id]),
			:in_bos_user_id      => a(:value => user[:user_id]){{}},
			:in_bos_password     => a(:value => "", :type =>"password" ){{}},
			:in_bos_mail_address => a(:value => user[:mail_address]){{}},
			:in_bos_sex          => {:user_sex => form_select(
				[{'f' => ''},{'m' => ''},{'o' => ''}],user[:sex])},
			:in_bos_birth   => a(:value => (user[:birth] ? user[:birth].to_sql : "")){{}},
			:in_bos_user_level   => {:user_level => form_select(
				[{'a' => ''},{'p' => '̥桼'},{'o' => ''}],user[:user_level])} }
		if user[:user_id] && user[:user_id] != "" then
			ret[:bos_user_id] = user[:user_id]
			ret[:in_bos_user_id] = nil
		else
			ret[:bos_user_id] = nil
			ret[:in_bos_user_id] = a(:values => user[:user_id])
		end
		ret
	else
		"¤ޤ"
	end
end

def bos_user_newlink
	a(:href => "?uid="){{}}
end

def bos_user_listlink
	a(:href => "?"){{}}
end

def bos_user_list_navi
	bos_user_list_pre unless @login_user_list
	page_navi(@login_user_maxpage,"page",{"pagect" => 10,:script_name => "user.htm"})
end

def bos_user_list
	bos_user_list_pre unless @login_user_list
	{:bos_user_list_rec => @login_user_list}
end

def bos_user_list_pre
	user = BosUser.new("")
	@login_user_list = []
	rec,info = @login_user.get_list(Request["page"],Request["pagect"])
	@login_user_maxpage = info[:max_page]
	rec.each{|rs|
		@login_user_list << {
			:bos_user_list_id    => rs[:user_id],
			:bos_user_list_level => rs[:user_level],
			:bos_user_list_edit  => a(:href => "?uid=#{rs[:user_id]}"){{}}} }
end

def bos_user_login
	return nil if Session['uid']
	{:bos_user_login_form => {
		:bos_user_login_uid => a(:name => "bos_user_login_uid", :value => (Request["bos_user_login_uid"] || "")){{}},
		:bos_user_login_pwd => a(:name => "bos_user_login_pwd", :value => ""){{}},
		:user_login_err => @bos_login_err
	}}
end

def bos_user_logout
	return nil unless Session['uid']
	true
end

def bos_user_login_user_id
	return nil unless @login_user
	{:user_id => @login_user[:user_id]}
end

def bos_user_admin_only_dev
	return nil unless @login_user
	@login_user == "a"
end

def bos_user_admin_only_page
	if @login_user && @login_user == "a" then
		# ǧʤ󤫤ää
	else
		print "Location: #{Prop[:site_url]}#{Prop[:err_doc]}\n\n"
	end
end

def bos_user_admin_items
	ret = []
	outpage = ["index","admside"]
	Dir.glob("#{Prop[:admin_dir]}/*.#{Prop[:bos_template]}").sort.each{|fl|
		if /.+\/(.+)\.#{Prop[:bos_template]}/ =~ fl then
			tmpt = $1
			ret << {:admin_item => a(:href => "#{tmpt}.#{Prop[:bos_template]}"){ tmpt } } unless outpage.include?(tmpt)
		end
	}
	ret
end

def bos_user_add_new
	ret = {
		:user_add_form => nil,
		:user_add_err => nil }
	if !Request["in_bos_user_id"] && !Request["in_bos_password"] then
		ret[:user_add_form] = true
	elsif Request["in_bos_user_id"] && Request["in_bos_password"] then
		tmpu = BosUser.new('')
		erm = tmpu.add_user(Request["in_bos_user_id"],Request["in_bos_password"])
		if erm then
			ret[:user_add_err] = erm
			ret[:user_add_form] = true
		else
			@login_user = BosUser.new(Request["in_bos_user_id"])
			@login_user[:mail_address] = Request["in_bos_mail_address"]
			@login_user.commit
			@login_user.login(Request["in_bos_password"])
			ret[:user_add_err] = "Ͽޤ"
		end
	else
		ret[:user_add_form] = {
			:in_bos_user_id => a(:values => Request["in_bos_user_id"] || ""),
			:in_bos_password => a(:values => ""),
			:in_bos_mail_address => a(:values => Request["in_bos_mail_address"] || ""),
		}
		ret[:user_add_err] = "IDȥѥɤϤƲ"
	end
	ret
end
